<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.0" language="bg">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation>Програмно прокси</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Тип прокси</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP Адрес</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Задължителен </translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Порт</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Потребителско име</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Допълнително</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Парола</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>Провери &quot;Отвори през прокси&quot; в контекстното меню на приложението в Лънчера след конфигуриране</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Отказ</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Запазване</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid port</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>Прекъсване</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Изтриване</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Отказ</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Запазване</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Свързване</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Прекъсване</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>Кабелна връзка: %1</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Хотспот</translation>
    </message>
    <message>
        <source>Wireless Connection %1</source>
        <translation>Безжична връзка: %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>PPPoE Връзка %1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>Нов VPN</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>Вид на VPN</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>Отвори VPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>Отвори Bръзка</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Изнасяне</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>Мрежа</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Програмно прокси</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Информация за мрежата</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Системен прокси сървър</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Кабелна мрежа</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Безжична мрежа</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation type="unfinished"/>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
        <extra-child_page>Wired Network</extra-child_page>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Добавяне на мрежова връзка</translation>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
        <extra-child_page>Wired Network</extra-child_page>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation type="unfinished"/>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
        <extra-child_page>Wireless Network</extra-child_page>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Свържи се към скрита мрежа</translation>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
        <extra-child_page>Wireless Network</extra-child_page>
    </message>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
        <extra-contents_path>/network/DSL</extra-contents_path>
        <extra-child_page_hide>DSL</extra-child_page_hide>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Създай PPPoE връзка</translation>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
        <extra-child_page>DSL</extra-child_page>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>VPN състояние</translation>
        <extra-contents_path>/network/VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Създай VPN</translation>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Ипортитане VPN</translation>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Тип прокси</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Конфигуриране на URL</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP Адрес</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Port</source>
        <translation>Порт</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Username</source>
        <translation>Потребителско име</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Password</source>
        <translation>Парола</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Хотспот</translation>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
        <extra-child_page>Personal Hotspot</extra-child_page>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation type="unfinished"/>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
        <extra-child_page>Personal Hotspot</extra-child_page>
    </message>
    <message>
        <source>Interface</source>
        <translation>Интерфейс</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Band</source>
        <translation>Лента</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Главен DNS</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Маска на мрежата</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Префикс</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Speed</source>
        <translation>Скорост</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>Ethernet</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Не е свързан</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>MAC адрес на устройството</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Клониран MAC адрес</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Персонализиране на MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>Общи</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Име</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Задължителен </translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>Общи</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Name</source>
        <translation>Име</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Задължителен </translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>Хотспот</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>Добави настройки</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>IP Адрес</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Задължителен </translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Маска на мрежата</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Задължителен </translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Префикс</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Автоматично</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ръчно</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Игнорирай</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP Адрес</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Задължителен </translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Прилага се само в съответните ресурси</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Метод</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Маска на мрежата</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Префикс</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network</source>
        <translation>Мрежа</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>Метод</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Автоматично</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ръчно</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Игнорирай</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>Информация за мрежата</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Системен прокси сървър</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Програмно прокси</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Информация за мрежата</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Мрежа</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Изключен</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ръчно</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Автоматично</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Потребителско име</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Задължителен </translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Услуга</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Парола</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Откажи EAP идентификация</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Откажи PAP идентификация</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Откажи CHAP идентификация</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Откажи MSCHAP идентификация</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Откажи MSCHAPv2 идентификация</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Няма BSD компресиране на данни</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Липсва компресиране на Deflate данни</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Липсва компресиране на TCP Header</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Липсва компресиране на Protocol Field</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Липсва Адресно/Контролно компресиране</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Изпращане на Echo Пакети</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Използвай MPPE</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>128-бит MPPE</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Статичен MPPE</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Създай PPPoE връзка</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>Системен прокси сървър</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Отказ</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Запазване</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Тип прокси</translation>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
        <extra-child_page>System Proxy</extra-child_page>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ръчно</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Автоматично</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Допълнително</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Порт</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP Прокси</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>HTTPS Прокси</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>FTP Прокси</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>SOCKS Proxy</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>Не използвай прокси за горните хостове и домейни</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Конфигуриране на URL</translation>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
        <extra-child_page>System Proxy</extra-child_page>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>Сигурност</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>FAST</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>Tunneled TLS</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>Защитен EAP</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ask me always</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Изключен</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Анонимен</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>Удостоверен</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>И двете</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Автоматичен</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Версия 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Версия 1</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>EAP Удостоверяване</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Идентификация</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Задължителен </translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Pwd настройки</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Доверен ключ</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA сертификат</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Потребителски сертификат</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>Анонимно ID</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>Провизиране</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>PAC Файл</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Вътрешно Удостоверяване</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>PEAP Версия</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Лична парола</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Парола</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>None</source>
        <translation>Нищо</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personal</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security</source>
        <translation>Сигурност</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Задължителен </translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Ключ</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Парола</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>Изисквания за сигурност</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>None</source>
        <translation>Нищо</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personal</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 Enterprise</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared key</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open system</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security</source>
        <translation>Сигурност</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Задължителен </translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Автентикация </translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Ключ</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Парола</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN Разширени настройки</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>Настройка на Gateway Порт</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>Gateway Порт</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>Настройка на Интервал на предоговаряне</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>Интервал на предоговаряне</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>Използвай LZO компресия на данни</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>Използвай TCP връзка</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>Използвай TAP устройство</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>Настройка на тунелен MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>Персонализирайте UDP размер на фрагмент</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>UDP Раздел на фрагмент</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>Ограничен тунелен TCP MSS</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>Хостове за случаен отдалечен достъп</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN Разширени настройки</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (по подразбиране)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Netscreen</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>Надеждна (по подразбиране)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Слаба</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Нищо</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T Когато е възможно (по подразбиране)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>NAT-T Винаги</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Изключен</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH Група 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH Група 2 (по подразбиране)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH Група 5</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>Сървър (по подразбиране)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DH Група 2</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Домейн</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Продавач</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Версия</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Описание</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>NAT Траверсивен режим</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>IKE DH Група</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>Напред Поверително</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>Локален Порт</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>Вдигане</translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>Включи IPsec</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Име на група</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>Групов ID</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Предварително споделен ключ</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>Фаза 1 Алгоритми</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>Фаза 2 Алгоритми</translation>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Задължителен </translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA сертификат</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Прокси</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Позволи Cisco Secure Desktop Trojan</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>CSD скрипт</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Потребителски сертификат</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Доверен ключ</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>Използвай FSID за основната парола</translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>Сертификати (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Парола</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>Сертификати с парола (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>Статичен ключ</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Запазен</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Питай</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Не се изисква</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Задължителен </translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Тип удостоверяване</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA сертификат</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Потребителски сертификат</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Доверен ключ</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Pwd настройки</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Лична парола</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Потребителско име</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Персонализиране на ключово направление</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>основно направление</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>Отдалечен IP адрес</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>Локален IP адрес</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>Всички достъпни (по подразбиране)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40-bit (най-малко надеждна)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128-bit (най-надеждна)</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Откажи EAP идентификация</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Откажи PAP идентификация</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Откажи CHAP идентификация</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Откажи MSCHAP идентификация</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Откажи MSCHAPv2 идентификация</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Няма BSD компресиране на данни</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Липсва компресиране на Deflate данни</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Липсва компресиране на TCP Header</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Липсва компресиране на Protocol Field</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Липсва Адресно/Контролно компресиране</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Изпращане на Echo Пакети</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Използвай MPPE</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Сигурност</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Статичен MPPE</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>VPN състояние</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Създай VPN</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Ипортитане VPN</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Грешка Импортиране</translation>
    </message>
    <message>
        <source>File error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation>ОК</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN Proxy</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Не се изисква</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Тип прокси</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP на сървър</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Задължителен </translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Порт</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>Повтаряй без прекъсване при неуспех</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Потребителско име</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Парола</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>CA Файл</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation>Игнориране на предупрежденията за сертификати</translation>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation>Използвайте TLS разширения на име на хост</translation>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>VPN Сигурност</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>По подразбиране</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Нищо</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Шифър</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>HMAC Удостоверяване</translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saved</source>
        <translation>Запазен</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Питай</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Не се изисква</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Задължителен </translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Потребителско име</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Pwd настройки</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Парола</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>NT Домейн</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN Proxy</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP на сървър</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Порт</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Потребителско име</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Парола</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Доверен ключ</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>SSH агент</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Предварително споделен ключ</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Задължителен </translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA сертификат</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Тип удостоверяване</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Потребителски сертификат</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Потребителско име</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Парола</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>Заявка за вътрешен IP адрес</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>Enforce UDP Encapsulation</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>Използвай IP компресия</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>Активирайте персонализирани предложения за шифроване</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>VPN TLS Удостоверяване</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>По подразбиране</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>Клиент</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Сървър</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>Наименование на обект</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>Тип сертификат за отдалечен достъп</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>Ключов файл</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Персонализиране на ключово направление</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>основно направление</translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saved</source>
        <translation>Запазен</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Питай</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Не се изисква</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Задължителен </translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Потребителско име</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Pwd настройки</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Парола</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Име на група</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Парола на група</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Използвай хибридно удостоверяване</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>CA Файл</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation>Първо включете мрежовия кабел</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Добавяне на мрежова връзка</translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>Избери настройки</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation type="unfinished"/>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation>Затвори хотспот</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Свържи се към скрита мрежа</translation>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
        <extra-child_page>WirelessPage</extra-child_page>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Не е свързан</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Задължителен </translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>MAC адрес на устройството</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Персонализиране на MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
</TS>